==> jc-1.4.0.tar.gz: polyglot/util/CachingTransformingList.h <==
// public class polyglot.util.CachingTransformingList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class b5f8c05aec5068ef polyglot_util_CachingTransformingList
// @dep_class c4f62a83dacbde47 polyglot_util_TransformingList

// header file dependencies
// @dep_header polyglot_util_TransformingList

#include "polyglot/util/TransformingList.h"

#ifndef _JC_polyglot_util_CachingTransformingList_H_
#define _JC_polyglot_util_CachingTransformingList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_util_Transformation$object;

// Typedefs
typedef struct _jc_polyglot_util_CachingTransformingList$sub_refs	_jc_polyglot_util_CachingTransformingList$sub_refs;
typedef struct _jc_polyglot_util_CachingTransformingList$sub_nonrefs	_jc_polyglot_util_CachingTransformingList$sub_nonrefs;
typedef struct _jc_polyglot_util_CachingTransformingList$refs	_jc_polyglot_util_CachingTransformingList$refs;
typedef struct _jc_polyglot_util_CachingTransformingList$nonrefs	_jc_polyglot_util_CachingTransformingList$nonrefs;
typedef struct _jc_polyglot_util_CachingTransformingList$object	_jc_polyglot_util_CachingTransformingList$object;

typedef const struct _jc_polyglot_util_CachingTransformingList$vmethods	_jc_polyglot_util_CachingTransformingList$vmethods;
typedef const struct _jc_polyglot_util_CachingTransformingList$vtable	_jc_polyglot_util_CachingTransformingList$vtable;
typedef const struct _jc_polyglot_util_CachingTransformingList$vtype	_jc_polyglot_util_CachingTransformingList$vtype;

// Constructors
extern void _jc_polyglot_util_CachingTransformingList$method$_init$687c4dce38d09c75(_jc_env *, struct _jc_polyglot_util_CachingTransformingList$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_polyglot_util_CachingTransformingList$method$_init$1cdc822f6d4e0ee2(_jc_env *, struct _jc_polyglot_util_CachingTransformingList$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_CachingTransformingList$method$get$a706240e1333824b(_jc_env *, struct _jc_polyglot_util_CachingTransformingList$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_CachingTransformingList$method_info$get$a706240e1333824b;

// Virtual methods structure
struct _jc_polyglot_util_CachingTransformingList$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_polyglot_util_CachingTransformingList$object *, jint);
};

// Vtable
struct _jc_polyglot_util_CachingTransformingList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_polyglot_util_TransformingList$vmethods	polyglot_util_TransformingList;
	_jc_polyglot_util_CachingTransformingList$vmethods	polyglot_util_CachingTransformingList;
};

// Vtype
struct _jc_polyglot_util_CachingTransformingList$vtype {
	_jc_type			type;
	_jc_polyglot_util_CachingTransformingList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_CachingTransformingList$sub_refs {
	struct _jc_java_util_ArrayList$object	*cache;
};

// Reference instance fields (object)
struct _jc_polyglot_util_CachingTransformingList$refs {
    _jc_polyglot_util_CachingTransformingList$sub_refs	polyglot_util_CachingTransformingList;
    _jc_polyglot_util_TransformingList$sub_refs	polyglot_util_TransformingList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_CachingTransformingList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_CachingTransformingList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_polyglot_util_TransformingList$sub_nonrefs	polyglot_util_TransformingList;
    _jc_polyglot_util_CachingTransformingList$sub_nonrefs	polyglot_util_CachingTransformingList;
};

// Object instance structure
struct _jc_polyglot_util_CachingTransformingList$object {
	_jc_polyglot_util_CachingTransformingList$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_CachingTransformingList$vtype	*vtype;
	_jc_polyglot_util_CachingTransformingList$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_CachingTransformingList$vtype _jc_polyglot_util_CachingTransformingList$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_CachingTransformingList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_CachingTransformingList$class_object;

#endif	/* _JC_polyglot_util_CachingTransformingList_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/CachingTransformingList.h <==
// public class polyglot.util.CachingTransformingList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class b5f8c05aec5068ef polyglot_util_CachingTransformingList
// @dep_class c4f62a83dacbde47 polyglot_util_TransformingList

// header file dependencies
// @dep_header polyglot_util_TransformingList

#include "polyglot/util/TransformingList.h"

#ifndef _JC_polyglot_util_CachingTransformingList_H_
#define _JC_polyglot_util_CachingTransformingList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_util_Transformation$object;

// Typedefs
typedef struct _jc_polyglot_util_CachingTransformingList$sub_refs	_jc_polyglot_util_CachingTransformingList$sub_refs;
typedef struct _jc_polyglot_util_CachingTransformingList$sub_nonrefs	_jc_polyglot_util_CachingTransformingList$sub_nonrefs;
typedef struct _jc_polyglot_util_CachingTransformingList$refs	_jc_polyglot_util_CachingTransformingList$refs;
typedef struct _jc_polyglot_util_CachingTransformingList$nonrefs	_jc_polyglot_util_CachingTransformingList$nonrefs;
typedef struct _jc_polyglot_util_CachingTransformingList$object	_jc_polyglot_util_CachingTransformingList$object;

typedef const struct _jc_polyglot_util_CachingTransformingList$vmethods	_jc_polyglot_util_CachingTransformingList$vmethods;
typedef const struct _jc_polyglot_util_CachingTransformingList$vtable	_jc_polyglot_util_CachingTransformingList$vtable;
typedef const struct _jc_polyglot_util_CachingTransformingList$vtype	_jc_polyglot_util_CachingTransformingList$vtype;

// Constructors
extern void _jc_polyglot_util_CachingTransformingList$method$_init$687c4dce38d09c75(_jc_env *, struct _jc_polyglot_util_CachingTransformingList$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_CachingTransformingList$method$_init$1cdc822f6d4e0ee2(_jc_env *, struct _jc_polyglot_util_CachingTransformingList$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_CachingTransformingList$method$get$a706240e1333824b(_jc_env *, struct _jc_polyglot_util_CachingTransformingList$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_CachingTransformingList$method_info$get$a706240e1333824b;

// Virtual methods structure
struct _jc_polyglot_util_CachingTransformingList$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_polyglot_util_CachingTransformingList$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_CachingTransformingList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_polyglot_util_TransformingList$vmethods	polyglot_util_TransformingList;
	_jc_polyglot_util_CachingTransformingList$vmethods	polyglot_util_CachingTransformingList;
};

// Vtype
struct _jc_polyglot_util_CachingTransformingList$vtype {
	_jc_type			type;
	_jc_polyglot_util_CachingTransformingList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_CachingTransformingList$sub_refs {
	struct _jc_java_util_ArrayList$object	*cache;
};

// Reference instance fields (object)
struct _jc_polyglot_util_CachingTransformingList$refs {
    _jc_polyglot_util_CachingTransformingList$sub_refs	polyglot_util_CachingTransformingList;
    _jc_polyglot_util_TransformingList$sub_refs	polyglot_util_TransformingList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_CachingTransformingList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_CachingTransformingList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_polyglot_util_TransformingList$sub_nonrefs	polyglot_util_TransformingList;
    _jc_polyglot_util_CachingTransformingList$sub_nonrefs	polyglot_util_CachingTransformingList;
};

// Object instance structure
struct _jc_polyglot_util_CachingTransformingList$object {
	_jc_polyglot_util_CachingTransformingList$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_CachingTransformingList$vtype	*vtype;
	_jc_polyglot_util_CachingTransformingList$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_CachingTransformingList$vtype _jc_polyglot_util_CachingTransformingList$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_CachingTransformingList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_CachingTransformingList$class_object;

#endif	/* _JC_polyglot_util_CachingTransformingList_H_ */
